You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ibatis.apache.org by ro...@apache.org on 2005/05/28 06:29:41 UTC

svn commit: r178857 - /incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs

Author: roberto
Date: Fri May 27 21:29:39 2005
New Revision: 178857

URL: http://svn.apache.org/viewcvs?rev=178857&view=rev
Log:
~Updated C# Common ResourcesTest.cs (spelling)

Modified:
    incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs?rev=178857&r1=178856&r2=178857&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs Fri May 27 21:29:39 2005
@@ -35,10 +35,10 @@
 		#region Test ResourcesTest
 
 		/// <summary>
 		/// Test loading Embeded Resource
 		/// </summary>
 		[Test] 
-		public void TestEmbededResource() 
+		public void TestEmbeddedResource() 
 		{
 			XmlDocument doc = null;
 
@@ -70,7 +70,7 @@
 		}
 
 		[Test] 
-		public void GetFileInfoWithAbsoluteProtocole() 
+		public void GetFileInfoWithAbsoluteProtocol() 
 		{ 
 			string resourcePath = "file://"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"IBatisNet.Common.Test.dll";
 			FileInfo fileInfo = Resources.GetFileInfo(resourcePath);
@@ -78,7 +78,7 @@
 		}
 
 		[Test] 
-		public void GetFileInfoWithAbsoluteProtocolePlusSlash() 
+		public void GetFileInfoWithAbsoluteProtocolPlusSlash() 
 		{ 
 			string resourcePath = "file:///"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"IBatisNet.Common.Test.dll";
 			FileInfo fileInfo = Resources.GetFileInfo(resourcePath);
@@ -89,7 +89,7 @@
 		#region GetConfigAsXmlDocument Tests
 
 		[Test] 
-		public void GetConfigAsXmlDocumentWithAbsolute() 
+		public void GetConfigAsXmlDocumentWithAbsolut() 
 		{ 
 			string resourcePath = Resources.ApplicationBase+Path.DirectorySeparatorChar+"SqlMap_MSSQL_SqlClient.config";
 			XmlDocument doc = Resources.GetConfigAsXmlDocument(resourcePath);
@@ -97,7 +97,7 @@
 		}
 
 		[Test] 
-		public void GetConfigAsXmlDocumentWithAbsoluteProtocole() 
+		public void GetConfigAsXmlDocumentWithAbsoluteProtocol() 
 		{ 
 			string resourcePath = "file://"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"SqlMap_MSSQL_SqlClient.config";
 			XmlDocument doc = Resources.GetConfigAsXmlDocument(resourcePath);
@@ -106,7 +106,7 @@
 
 
 		[Test] 
-		public void GetConfigAsXmlDocumentWithAbsoluteProtocolePlusSlash() 
+		public void GetConfigAsXmlDocumentWithAbsoluteProtocolPlusSlash() 
 		{ 
 			XmlDocument doc = Resources.GetConfigAsXmlDocument("file:///"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"SqlMap_MSSQL_SqlClient.config");
 			Assert.IsNotNull(doc);
@@ -35,10 +35,10 @@
 
 		/// <summary>
-		/// Test loading Embeded Resource
+		/// Test loading Embedded Resource
 		/// </summary>
 		[Test] 



Re: svn commit: r178857 - /incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs

Posted by Gilles Bayon <ib...@gmail.com>.
Argh

On 5/28/05, roberto@apache.org <ro...@apache.org> wrote: 
> 
> Author: roberto
> Date: Fri May 27 21:29:39 2005
> New Revision: 178857
> 
> URL: http://svn.apache.org/viewcvs?rev=178857&view=rev
> Log:
> ~Updated C# Common ResourcesTest.cs (spelling)
> 
> Modified:
> 
> incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs
> 
> Modified: 
> incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs
> URL: 
> http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs?rev=178857&r1=178856&r2=178857&view=diff
> 
> ==============================================================================
> --- 
> incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs 
> (original)
> +++ 
> incubator/ibatis/trunk/cs/mapper/IBatisNet.Common.Test/NUnit/CommonTests/Utilities/ResourcesTest.cs 
> Fri May 27 21:29:39 2005
> @@ -35,10 +35,10 @@
> #region Test ResourcesTest
> 
> /// <summary>
> - /// Test loading Embeded Resource
> + /// Test loading Embedded Resource
> /// </summary>
> [Test]
> - public void TestEmbededResource()
> + public void TestEmbeddedResource()
> {
> XmlDocument doc = null;
> 
> @@ -70,7 +70,7 @@
> }
> 
> [Test]
> - public void GetFileInfoWithAbsoluteProtocole()
> + public void GetFileInfoWithAbsoluteProtocol()
> {
> string resourcePath = 
> "file://"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"
> IBatisNet.Common.Test.dll";
> FileInfo fileInfo = Resources.GetFileInfo(resourcePath);
> @@ -78,7 +78,7 @@
> }
> 
> [Test]
> - public void GetFileInfoWithAbsoluteProtocolePlusSlash()
> + public void GetFileInfoWithAbsoluteProtocolPlusSlash()
> {
> string resourcePath = 
> "file:///"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"
> IBatisNet.Common.Test.dll";
> FileInfo fileInfo = Resources.GetFileInfo(resourcePath);
> @@ -89,7 +89,7 @@
> #region GetConfigAsXmlDocument Tests
> 
> [Test]
> - public void GetConfigAsXmlDocumentWithAbsolute()
> + public void GetConfigAsXmlDocumentWithAbsolut()
> {
> string resourcePath = 
> Resources.ApplicationBase+Path.DirectorySeparatorChar+
> "SqlMap_MSSQL_SqlClient.config";
> XmlDocument doc = Resources.GetConfigAsXmlDocument(resourcePath);
> @@ -97,7 +97,7 @@
> }
> 
> [Test]
> - public void GetConfigAsXmlDocumentWithAbsoluteProtocole()
> + public void GetConfigAsXmlDocumentWithAbsoluteProtocol()
> {
> string resourcePath = 
> "file://"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"SqlMap_MSSQL_SqlClient.config";
> XmlDocument doc = Resources.GetConfigAsXmlDocument(resourcePath);
> @@ -106,7 +106,7 @@
> 
> 
> [Test]
> - public void GetConfigAsXmlDocumentWithAbsoluteProtocolePlusSlash()
> + public void GetConfigAsXmlDocumentWithAbsoluteProtocolPlusSlash()
> {
> XmlDocument doc = Resources.GetConfigAsXmlDocument
> ("file:///"+Resources.ApplicationBase+Path.DirectorySeparatorChar+"SqlMap_MSSQL_SqlClient.config");
> Assert.IsNotNull(doc);
> 
> 
>